@@ -10,9 +10,11 @@ from symbl_rest.api.authentication_api import AuthenticationApi
 from symbl_rest.api.connection_to_endpoint_api import ConnectionToEndpointApi
 from symbl_rest.api.conversation_data_api import ConversationDataApi
 from symbl_rest.api.conversations_api import ConversationsApi
+from symbl_rest.api.delete_conversation_api import DeleteConversationApi
 from symbl_rest.api.entities_api import EntitiesApi
 from symbl_rest.api.external_event_web_hook_api import ExternalEventWebHookApi
 from symbl_rest.api.follow_ups_api import FollowUpsApi
+from symbl_rest.api.formatted_transcript_api import FormattedTranscriptApi
 from symbl_rest.api.insights_api import InsightsApi
 from symbl_rest.api.intents_api import IntentsApi
 from symbl_rest.api.jobs_api import JobsApi
